#
# spec file for package xpra-html5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define uglifyjs_version 3.17.4
%define minifier uglifyjs
%define python python3

Name:           xpra-html5
Release:        lp156.2.4
Version:        7.0+git20221227.017148e
Summary:        HTML5 client for Xpra
License:        GPL-2.0+ AND BSD-3-Clause AND LGPL-3.0+ AND MIT
URL:            https://xpra.org/
Source0:        xpra-html5-%{version}.tar.gz
### To update UglifyJS using npm release:
###   npm pack uglify-js
### To update UglifyJS using github release:
###   osc service runall download_files
#Source1:        https://registry.npmjs.org/uglify-js/-/uglify-js-%%{uglifyjs_ver}.tgz#/uglify-js-%%{uglifyjs_version}.tgz
Source1:        https://github.com/mishoo/UglifyJS/archive/refs/tags/v%{uglifyjs_version}.tar.gz#/uglify-js-%{uglifyjs_version}.tar.gz
#####
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  nodejs-common
BuildRequires:  python3
Requires:       cups-client
Requires:       dejavu-fonts
Requires:       qrencode
Requires:       xpra
Requires:       python3-avahi
Requires:       python3-netifaces
Requires:       python3-paramiko
Requires:       python3-pyinotify
Requires:       python3-pyxdg
Requires:       python3-websockify
Requires:       python3-zeroconf
Provides:       bundled(js-aurora)
Provides:       bundled(js-bencode)
Provides:       bundled(js-broadway)
Provides:       bundled(js-forge)
Provides:       bundled(js-jquery) = 3.1.1
Provides:       bundled(js-jquery-ui) = 1.12.1
Provides:       bundled(js-lz4)
Provides:       bundled(js-zlib)
BuildArch:      noarch
ExcludeArch:    %ix86

%description
This is the HTML5 client for Xpra,
which can be made available for browsers by the xpra server
or by any other web server.

%prep
%setup -q -a 1

%build
### intentionally left empty.

%install

### Debug info for proper uglifyjs setup
echo -e "\nUGLIFYJS -check1 :: $(which uglifyjs)\n"
echo -e "\nPATH: '$PATH'\n"
echo -e "\nPWD: '$(pwd)'\n"
echo -e "%{name} :: %{version}"
find . -iname uglifyjs -exec ls -ld {} \;
### Using npm download
#export PATH=$PATH:$(pwd)/package/bin
#chmod -v 755 %%{_builddir}/%%{name}-%%{version}/package/bin/uglifyjs
#ls -l %%{_builddir}/%%{name}-%%{version}/package/bin
#####
export PATH=$PATH:$(pwd)/UglifyJS-%{uglifyjs_version}/bin
chmod -v 755 %{_builddir}/%{name}-%{version}/UglifyJS-%{uglifyjs_version}/bin/uglifyjs
ls -l %{_builddir}/%{name}-%{version}/UglifyJS-%{uglifyjs_version}/bin
find . -iname uglifyjs -exec ls -ld {} \;
echo -e "\nUGLIFYJS -check2 :: $(which uglifyjs)\n"
#####

mkdir -p %{buildroot}%{_datadir}/xpra/www/js/lib
mkdir -p %{buildroot}%{_sysconfdir}/xpra/html5-client
%{python} ./setup.py install %{buildroot} %{_datadir}/xpra/www/ %{_sysconfdir}/xpra/html5-client %{minifier}
# Ensure there are no executable files:
find %{buildroot}%{_datadir}/xpra/www/ -type f -exec chmod 0644 {} \;
mkdir -p %{buildroot}/usr/share/doc/xpra-html5/

%fdupes -s %{buildroot}

%files
%dir %{_sysconfdir}/xpra
%{_sysconfdir}/xpra/html5-client
%config %{_sysconfdir}/xpra/html5-client/default-settings.txt
%{_datadir}/xpra
%{_datadir}/xpra/www

%changelog
* Tue Dec 27 2022 scott.bradnick@suse.com
- Update to version 7.0+git20221227.017148e:
  * workaround for setuptools breakage in version 61 and later
  * typo
  * Linting
  * firefox cancas flicker
  * bitmap_options.set() is not defined
  * throttle fix
* Tue Nov 29 2022 scott.bradnick@suse.com
- Update to version 7.0+git20221031.f1e0fa1:
  * forgot to bump version here
  * #210 brackets change the event handler scope somehow?
  * Hotfix in OffscreenDecodeWorker
* Mon Oct 24 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update uglifyjs to '3.17.4'
* Tue Oct 18 2022 scott.bradnick@suse.com
- Update uglifyjs to '3.17.3'
- Update to version 6.0+git20221017.21cabde:
  * bump version
  * update the release notes
  * modernize - require python3
  * bump revision
  * typo: missing '%%'
  * better wording
  * #204 don't allow modal windows to be minimized
* Sat Oct  1 2022 scott.bradnick@suse.com
- Update uglifyjs to '3.17.2'
- Update to version 6.0+git20220926.c248091:
  * linting
  * linting
  * update release no
  * fix el9 builds
  * update the release notes
  * bump release no
  * Move paint, add css class
  * #198 send decode errors to the server
  * typo
  * typo
  * only validate the frame type if it is specified
  * #198 default to medium quality when upscaling
  * #198 don't set any 'resize' options when not using scaling
* Fri Aug 19 2022 scott.bradnick@suse.com
- Updating uglifyjs to '3.17.0'
- Update to version 5.0+git20220805.f4e08d5:
  * update revision no
  * downmerg
  * linting
  * redraw
  * linting
  * linting
  * trailing comma
  * width/height
  * resizeQuality
  * requestAnimationFrame in worker
  * fix void and scroll
  * restore compatibility with older servers
  * use the new keyboard mapping attributes
  * VPX
  * XpraImageDecoder
  * ImageDecoder
  * 2 spaces
  * WIP
* Tue Jul 19 2022 scott.bradnick@suse.com
- Update to version 5.0+git20220718.17c39ca:
  * Fix for #188
  * simplify
  * fix broken legacy clipboard
  * use the version agnostic package name
  * #188 need arrow function to use 'this'
* Tue Jun 21 2022 scott.bradnick@suse.com
- Update to version 5.0+git20220610.56f906c:
  * brotli return value needs casting
  * remove leftover bencode support
  * more useful error: log protocol flags and packet data
  * show builds from 'git master' as 'beta' builds
  * Remove bencode lib
  * fix sound-data buffer check
  * these packet encoder workarounds are no longer necessary
  * fix beep
  * require 'rencodeplus' and remove bencode + plain rencode
  * remove zlib
  * Allow up to 3 repeats of strings
  * De-index-ify for loops without using `[index, element]` syntax
  * Format .json files in pre-commit hook
  * Silence warnings from format script
  * Extract all packet types into constants
  * Organize client string constants
  * Simplify prototype calls with `Object.hasOwn`
  * Rename image variable for clarity
  * Simplify trivial (& error-prone) indexing operations
  * Rename keystring variable for clarity
  * Downgrade remaining GitHub lint errors to warnings, for future fixing
  * Simplify confusing function declaration
  * Flatten nested template string
  * Fix auto-fixable GitHub lint errors
  * Add GitHub lint plugin to find & fix code smells
  * Downgrade remaining unicorn lint errors to warnings, for future fixing
  * Rename all JS files to PascalCase for consistency
  * Simplify constructed booleans
  * Prefer `.querySelector()` for consistency
  * Remove "use strict" directives to embrace JS modules
  * Expand abbreviations in variable names
  * Fix auto-fixable unicorn lint errors
  * Turn off a rule with broken auto-fix
  * Turn off a rule that caused problems in the past
  * Add unicorn lint plugin to find & fix code smells
  * Simplify duplicate functions to soften redundancy
  * Simplify boolean expressions
  * De-duplicate debug/error/log utility methods
  * Merge trivially-nested if statements
  * Consolidate url construction into a Window class method
  * Deduplicate string literals with new constants
  * Add SonarJS lint plugin to find code smells
  * Upgrade turned-off (but useful) lint rules to warnings
  * Lint-ignore sw.js
  * Undo sw.js formatting from #178
  * #189 guard against client being unset, somehow
* Wed Jun  1 2022 scott.bradnick@suse.com
- Update to version 5.0+git20220601.d52ebb5:
  * #188 only consume the event when over a window
* Tue May 31 2022 scott.bradnick@suse.com
- Update to version 5.0+git20220531.9ebe126:
  * access client via 'this'
  * fix another non-offscreen paint error
  * we don't check but we do support these
  * fixup c534ab0d839c7b5501fd83f96a6da6af69aaea5a
  * fix challenge response handler
  * Update VideoDecoder.js
  * #190 running install is usually enough
  * #190 make it clearer one can just run install
  * #183 fix non-decode worker paints
  * Remove all commented-out code
* Wed May 25 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding a few more 'Requires' to cleanup runtime warnings/errors.
* Mon May 23 2022 scott.bradnick@suse.com
- Updating uglifyjs to '3.15.5'.
- Update to version 5.0+git20220516.caf9971:
  * Last known commit working w/o error(s).
* Wed Apr 27 2022 scott.bradnick@suse.com
- Update to version 4.5.2+git20220421.ecc3a08:
  * Added keycloak authentication
- Switching UglifyJS source from npmjs source url to github source url.
* Tue Apr 19 2022 Scott Bradnick <scott.bradnick@suse.com>
- Updating uglifyjs to '3.15.4'.
* Tue Apr 19 2022 scott.bradnick@suse.com
- Update to version 4.5.2+git20220413.dc3077b:
  * tell the server to use 'scroll' encoding less
* Tue Apr  5 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adjusting top copyright comments.
* Tue Mar 29 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'git-core' as a BuildRequires.
* Tue Mar 29 2022 Scott Bradnick <scott.bradnick@suse.com>
- Inadvertently left out 'BuildRequires:  python3'.
* Tue Mar 29 2022 scott.bradnick@suse.com
- Update to version git20220322.82199bc:
  * make debug logging clearer
  * do log the decode worker instance
  * reduce the amount of audio codec logging
  * add GHA
  * #162 don't use join with a potentially empty root
  * #162 create install dir if needed
  * we already lookup cwd just once, do it early
  * show help if subcommand is invalid
* Tue Mar 29 2022 Scott Bradnick <scott.bradnick@suse.com>
- Initial version for xpra-html5 pulled out of 'xpra.spec'.
